Renamed burst sink/source to burst file sink/source
diff --git a/include/grgsm/CMakeLists.txt b/include/grgsm/CMakeLists.txt
index fd44c54..a16c076 100644
--- a/include/grgsm/CMakeLists.txt
+++ b/include/grgsm/CMakeLists.txt
@@ -32,4 +32,4 @@
 add_subdirectory(demapping)
 add_subdirectory(receiver)
 add_subdirectory(misc_utils)
-
+add_subdirectory(qa_utils)
diff --git a/include/grgsm/misc_utils/CMakeLists.txt b/include/grgsm/misc_utils/CMakeLists.txt
index 18c2860..527ae51 100644
--- a/include/grgsm/misc_utils/CMakeLists.txt
+++ b/include/grgsm/misc_utils/CMakeLists.txt
@@ -22,16 +22,12 @@
 ########################################################################
 install(FILES
     bursts_printer.h
-    burst_sink.h
-    burst_source.h
-    burst_sink_qa.h
-    burst_source_qa.h
+    burst_file_source.h
+    burst_file_sink.h
     extract_system_info.h
     extract_immediate_assignment.h
     controlled_rotator_cc.h
     controlled_const_source_f.h
     message_printer.h
-    tmsi_dumper.h
-    message_source.h
-    message_sink.h DESTINATION include/grgsm/misc_utils
+    tmsi_dumper.h DESTINATION include/grgsm/misc_utils
 )
diff --git a/include/grgsm/misc_utils/burst_sink.h b/include/grgsm/misc_utils/burst_file_sink.h
similarity index 75%
rename from include/grgsm/misc_utils/burst_sink.h
rename to include/grgsm/misc_utils/burst_file_sink.h
index 6903df9..7263baa 100644
--- a/include/grgsm/misc_utils/burst_sink.h
+++ b/include/grgsm/misc_utils/burst_file_sink.h
@@ -20,8 +20,8 @@
  *
  */
 
-#ifndef INCLUDED_GSM_BURST_SINK_H
-#define INCLUDED_GSM_BURST_SINK_H
+#ifndef INCLUDED_GSM_BURST_FILE_SINK_H
+#define INCLUDED_GSM_BURST_FILE_SINK_H
 
 #include <grgsm/api.h>
 #include <gnuradio/block.h>
@@ -34,17 +34,17 @@
      * \ingroup gsm
      *
      */
-    class GSM_API burst_sink : virtual public gr::block
+    class GSM_API burst_file_sink : virtual public gr::block
     {
      public:
-      typedef boost::shared_ptr<burst_sink> sptr;
+      typedef boost::shared_ptr<burst_file_sink> sptr;
 
       /*!
        * \brief Return a shared_ptr to a new instance of grgsm::burst_sink.
        *
        * To avoid accidental use of raw pointers, grgsm::burst_sink's
        * constructor is in a private implementation
        * class. grgsm::burst_sink::make is the public interface for
        * creating new instances.
        */
       static sptr make(const std::string &filename);
@@ -52,5 +52,5 @@
   } // namespace gsm
 } // namespace gr
 
-#endif /* INCLUDED_GSM_BURST_SINK_H */
+#endif /* INCLUDED_GSM_BURST_FILE_SINK_H */
 
@@ -34,17 +34,17 @@
 
       /*!
-       * \brief Return a shared_ptr to a new instance of grgsm::burst_sink.
+       * \brief Return a shared_ptr to a new instance of grgsm::burst_file_sink.
        *
@@ -34,17 +34,17 @@
        *
-       * To avoid accidental use of raw pointers, grgsm::burst_sink's
+       * To avoid accidental use of raw pointers, grgsm::burst_file_sink's
        * constructor is in a private implementation
@@ -34,17 +34,17 @@
        * constructor is in a private implementation
-       * class. grgsm::burst_sink::make is the public interface for
+       * class. grgsm::burst_file_sink::make is the public interface for
        * creating new instances.
        */
diff --git a/include/grgsm/misc_utils/burst_source.h b/include/grgsm/misc_utils/burst_file_source.h
similarity index 75%
rename from include/grgsm/misc_utils/burst_source.h
rename to include/grgsm/misc_utils/burst_file_source.h
index bd8644f..e18ef44 100644
--- a/include/grgsm/misc_utils/burst_source.h
+++ b/include/grgsm/misc_utils/burst_file_source.h
@@ -20,8 +20,8 @@
  *
  */
 
-#ifndef INCLUDED_GSM_BURST_SOURCE_H
-#define INCLUDED_GSM_BURST_SOURCE_H
+#ifndef INCLUDED_GSM_BURST_FILE_SOURCE_H
+#define INCLUDED_GSM_BURST_FILE_SOURCE_H
 
 #include <grgsm/api.h>
 #include <gnuradio/block.h>
@@ -34,17 +34,17 @@
      * \ingroup gsm
      *
      */
-    class GSM_API burst_source : virtual public gr::block
+    class GSM_API burst_file_source : virtual public gr::block
     {
      public:
-      typedef boost::shared_ptr<burst_source> sptr;
+      typedef boost::shared_ptr<burst_file_source> sptr;
 
       /*!
        * \brief Return a shared_ptr to a new instance of grgsm::burst_source.
        *
        * To avoid accidental use of raw pointers, grgsm::burst_source's
        * constructor is in a private implementation
        * class. grgsm::burst_source::make is the public interface for
        * creating new instances.
        */
       static sptr make(const std::string &filename);
@@ -53,5 +53,5 @@
   } // namespace gsm
 } // namespace gr
 
-#endif /* INCLUDED_GSM_BURST_SOURCE_H */
+#endif /* INCLUDED_GSM_BURST_FILE_SOURCE_H */
@@ -34,17 +34,17 @@
 
       /*!
-       * \brief Return a shared_ptr to a new instance of grgsm::burst_source.
+       * \brief Return a shared_ptr to a new instance of grgsm::burst_file_source.
        *
@@ -34,17 +34,17 @@
        *
-       * To avoid accidental use of raw pointers, grgsm::burst_source's
+       * To avoid accidental use of raw pointers, grgsm::burst_file_source's
        * constructor is in a private implementation
@@ -34,17 +34,17 @@
        * constructor is in a private implementation
-       * class. grgsm::burst_source::make is the public interface for
+       * class. grgsm::burst_file_source::make is the public interface for
        * creating new instances.
        */